@@ -18,6 +18,9 @@
 #ifndef __FN_CLIENT_UTIL_H__
 #define __FN_CLIENT_UTIL_H__
 
-int freenet_parse_redirect (freenet_key *key, const unsigned char *metadata);
+int freenet_parse_redirect (freenet_key *key, const char *metadata);
+
+int freenet_parse_mapfile (freenet_key *key, const char *metadata,
+                           const char *docname);
 
 #endif /* __FN_CLIENT_UTIL_H__ */
