@@ -18,14 +18,16 @@
 #ifndef __FN_ENDTOEND_H__
 #define __FN_ENDTOEND_H__
 
-__inline__ int endtoend_init (freenet_transfer_state *state,
+#include "client.h"
+
+__inline__ int endtoend_init (freenet_client_stream *cstream,
                               unsigned char *key);
 
-__inline__ int endtoend_encrypt (freenet_transfer_state *state,
+__inline__ int endtoend_encrypt (freenet_client_stream *cstream,
                                  unsigned char *inbuffer,
                                  unsigned char *outbuffer, int len);
 
-__inline__ int endtoend_decrypt (freenet_transfer_state *state,
+__inline__ int endtoend_decrypt (freenet_client_stream *cstream,
                                  unsigned char *inbuffer,
                                  unsigned char *outbuffer, int len);
 
