@@ -18,17 +18,24 @@
 #ifndef __FN_UTIL_H__
 #define __FN_UTIL_H__
 
+#include <stream.h>
 
 int readall(int sock, unsigned char *buffer, int len);
 
 int writeall(int sock, unsigned char *buffer, int len);
 
-int raw_to_bagbiting_freenet_mpi(unsigned char *x, int xlen,
-                                 unsigned char *bfmpi);
+int raw_to_bagbiting_freenet_mpi (unsigned char *x, int xlen,
+                                  unsigned char *bfmpi);
 
 int keygen (const unsigned char *k, int klen, unsigned char *key,
             int keybytes);
 
 int generate_random(unsigned char *buffer, int len);
 
+int sign (freenet_group *group, unsigned char *priv, unsigned char *pub,
+          unsigned char *buf, int len, unsigned char *sigstr);
+
+int verify (freenet_group *group, unsigned char *pub,
+            unsigned char *buf, int len, unsigned char *sigstr);
+
 #endif /* __FN_UTIL_H__ */
