@@ -35,14 +35,12 @@
 #include "protocol.h"
 #include "util.h"
 
-int hex2uint64(const char *string, u_int64_t *val);
-
 int readall(int sock, unsigned char *buffer, int len);
 
 int writeall(int sock, unsigned char *buffer, int len);
 
 int open_connection (freenet_connection *connection, char *hostaddress,
-                     char *service);
+                     int port);
 
 int get_connection(freenet_connection *connection, u_short port,
                    time_t timeout);
@@ -52,7 +50,7 @@ int diffie_hellman (freenet_connection *connection, unsigned char *k,
 
 int start_ciphers (freenet_connection *connection, unsigned char *key);
 
-int request_handshake (freenet_connection *connection);
+int request_handshake(freenet_connection *connection);
 
 int reply_handshake (freenet_connection *connection, freenet_message *request);
 
@@ -64,11 +62,105 @@ int internal_recvmsg (freenet_connection *connection,
                       freenet_message *message);
 
 
+static const struct {
+        const char *str;
+        int type;
+} msgtypes[] = {
+        { "StoreData", FN_STOREDATA_MSG },
+        { "HandshakeRequest", FN_HANDSHAKEREQUEST_MSG },
+        { "HandshakeReply", FN_HANDSHAKEREPLY_MSG },
+        { "QueryRestarted", FN_QUERYRESTARTED_MSG },
+        { "DataRequest", FN_DATAREQUEST_MSG },
+        { "DataReply", FN_DATAREPLY_MSG },
+        { "TimedOut", FN_TIMEDOUT_MSG },
+        { "RequestFailed", FN_REQUESTFAILED_MSG },
+        { "InsertRequest", FN_INSERTREQUEST_MSG },
+        { "InsertReply", FN_INSERTREPLY_MSG },
+        { "DataInsert", FN_DATAINSERT_MSG },
+        { NULL, FN_UNKNOWN_MSG }
+};
+
+
+static struct {
+  const char *str;
+  int status;
+} errstrs[] = {
+  { "Success", FNS_SUCCESS },
+  { "Invalid port", FNS_INVALID_PORT },
+  { "Invalud address", FNS_INVALID_ADDY },
+  { "connect(2) failed", FNS_CONNECT_FAILED },
+  { "socket(2) failed", FNS_SOCKET_FAILED },
+  { "bind(2) failed", FNS_BIND_FAILED },
+  { "listen(2) failed", FNS_LISTEN_FAILED },
+  { "accept(2) failed", FNS_LISTEN_FAILED },
+  { "write(2) failed", FNS_WRITE_FAILED },
+  { "read(2) failed", FNS_READ_FAILED },
+  { "malloc(3) failed", FNS_MALLOC_FAILED },
+  { "Invalid MPint", FNS_INVALID_MPINT },
+  { "Invalid DHK", FNS_INVALID_DHK },
+  { "mhash failed", FNS_MHASH_FAILED },
+  { "Hash too small", FNS_HASH_TOO_SMALL },
+  { "makekey failed", FNS_MAKEKEY_FAILED },
+  { "Cipher init failed", FNS_CIPHERINIT_FAILED },
+  { "Encrypt failed", FNS_ENCRYPT_FAILED },
+  { "Invalid reply", FNS_INVALID_REPLY },
+  { "Invalid version", FNS_INVALID_VERSION },
+  { "Wrong ID", FNS_WRONG_ID },
+  { "Random error", FNS_RANDOM_ERROR },
+  { "open(2) failed", FNS_OPEN_FAILED },
+  { "Overread", FNS_OVERREAD },
+  { "Invalid request", FNS_INVALID_REQUEST },
+  { "Connection gone", FNS_CONNECTION_GONE },
+  { "End of file", FNS_EOF },
+  { "Overwrite", FNS_OVERWRITE },
+  { "Invalid data", FNS_INVALID_DATA },
+  { "Unexpected key length", FNS_UNEXPECTED_KEY_LENGTH },
+  { "Bad key", FNS_BAD_KEY },
+  { "Zero data length", FNS_ZERO_DATALEN },
+  { "Timeout", FNS_TIMEOUT },
+  { "Request failed", FNS_REQUEST_FAILED },
+  { "Unexpected message", FNS_UNEXPECTED_MESSAGE },
+  { "Buffer too small", FNS_BUFFER_TOO_SMALL },
+  { "Invalid end-to-end", FNS_INVALID_ENDTOEND },
+  { "Invalid metadata length", FNS_INVALID_METADATA_LEN },
+  { "BN failed", FNS_BN_FAILED },
+  { "DH failed", FNS_DH_FAILED },
+  { "BAD_CTRL", FNS_BAD_CTRL },
+  { "Bad hash", FNS_BAD_HASH },
+  { "Invalid URI", FNS_INVALID_URI },
+  { "Unknown keytype", FNS_UNKNOWN_KEYTYPE },
+  { "Invalid search key", FNS_INVALID_SEARCHKEY },
+  { "Invalid enc key", FNS_INVALID_ENCKEY },
+  { "DSA failed", FNS_DSA_FAILED },
+  { "Invalid private key", FNS_INVALID_PRIVATE_KEY },
+  { "fseek(3) failed", FNS_FSEEK_FAILED },
+  { "Data reply", FNS_DATA_REPLY },
+  { "SVK too large", FNS_SVK_TOO_LARGE },
+  { "Invalid signature", FNS_INVALID_SIG },
+  { "Invalid public key", FNS_INVALID_PUBKEY },
+  { "Invalid end2end", FNS_INVALID_E2E },
+  { "Unknown message type", FNS_UNKNOWN_MSG_TYPE },
+  { "Bad trailing field", FNS_BAD_TRAILING_FIELD },
+  { "Not a redirect", FNS_NOT_A_REDIRECT },
+  { "Invalid redirect", FNS_INVALID_REDIRECT },
+  { "Invalid 64-bit hexlen", FNS_INVALID_64BIT_HEXLEN },
+  { "Invalid hex character", FNS_INVALID_HEX_CHAR },
+  { "fcntl(2) failed", FNS_FCNTL_FAILED },
+  { "accept(2) timed out", FNS_ACCEPT_TIMEDOUT },
+  { "mktime(3) failed", FNS_MKTIME_FAILED },
+  { "Not a mapfile", FNS_NOT_A_MAPFILE },
+  { "Invalid mapfile", FNS_INVALID_MAPFILE },
+  { "Docname not found", FNS_DOCNAME_NOT_FOUND },
+  { NULL, 0 }
+};
+
+
 /* Convert a hex string to a 64-bit unsigned int.  I hate my life. */
-int hex2uint64(const char *string, u_int64_t *val)
+__inline__ int hex2uint64(const char *string, u_int64_t *val)
 {
   int i;
   int len;
+  char c;
   u_int64_t mult[16] = {
     0x0000000000000001,
     0x0000000000000010,
@@ -96,55 +188,12 @@ int hex2uint64(const char *string, u_int64_t *val)
   }
 
   for (i=0; i<len; i++) {
-    switch (tolower(string[(len-1)-i])) {
-    case '0':
-      break;
-    case '1':
-      *val += (0x1 * mult[i]);
-      break;
-    case '2':
-      *val += (0x2 * mult[i]);
-      break;
-    case '3':
-      *val += (0x3 * mult[i]);
-      break;
-    case '4':
-      *val += (0x4 * mult[i]);
-      break;
-    case '5':
-      *val += (0x5 * mult[i]);
-      break;
-    case '6':
-      *val += (0x6 * mult[i]);
-      break;
-    case '7':
-      *val += (0x7 * mult[i]);
-      break;
-    case '8':
-      *val += (0x8 * mult[i]);
-      break;
-    case '9':
-      *val += (0x9 * mult[i]);
-      break;
-    case 'a':
-      *val += (0xa * mult[i]);
-      break;
-    case 'b':
-      *val += (0xb * mult[i]);
-      break;
-    case 'c':
-      *val += (0xc * mult[i]);
-      break;
-    case 'd':
-      *val += (0xd * mult[i]);
-      break;
-    case 'e':
-      *val += (0xe * mult[i]);
-      break;
-    case 'f':
-      *val += (0xf * mult[i]);
-      break;
-    default:
+    c = tolower(string[(len-1)-i]);
+    if ((c >= 'a') && (c <= 'f')) {
+      *val += (((c - 'a') + 10) * mult[i]);
+    } else if ((c >= '0') && (c <= '9')) {
+      *val += ((c - '0') * mult[i]);
+    } else {
       return FNS_INVALID_HEX_CHAR;
     }
   }
@@ -154,28 +203,47 @@ int hex2uint64(const char *string, u_int64_t *val)
 }
 
 
+__inline__ int string_to_msgtype (const char *typestr)
+{
+  int result = FN_UNKNOWN_MSG;
+  int i;
+
+  for(i = 0; msgtypes[i].str != NULL; i++) {
+    if(strcmp(msgtypes[i].str, typestr) == 0) {
+      result=msgtypes[i].type;
+      break;
+    }
+  }
+
+  return result;
+}
+
+
+__inline__ int msgtype_to_string (int msgtype, char *typestr)
+{
+  int i;
+
+  for(i = 0; msgtypes[i].str != NULL; i++) {
+    if(msgtypes[i].type == msgtype) {
+      strcpy(typestr, msgtypes[i].str);
+      return FNS_SUCCESS;
+    }
+  }
+  return FNS_UNKNOWN_MSG_TYPE;
+}
+
+
 /* just open a tcp connection */
 int open_connection (freenet_connection *connection, char *hostaddress,
-                     char *service)
+                     int port)
 {
   struct in_addr addr;
   int connected_socket, connected;
   struct sockaddr_in address;
-  struct servent *serv;
-  long lport;
-  char *errpos;
   struct hostent *host;
-  int port = -1;
 
-  serv = getservbyname(service, "tcp");
-  if (serv != NULL)
-    port = serv->s_port;
-  else { /* Not in services, maybe a number? */
-    lport = strtol(service,&errpos,0);
-    if ( (errpos[0] != 0) || (lport < 1) || (lport > 65535) ) {
-      return FNS_INVALID_PORT;
-    }
-    port = htons(lport);
+  if ( (port < 1) || (port > 65535) ) {
+    return FNS_INVALID_PORT;
   }
 
   addr.s_addr = inet_addr(hostaddress);
@@ -189,7 +257,7 @@ int open_connection (freenet_connection *connection, char *hostaddress,
 
   memset((char *) &address, 0, sizeof(address));
   address.sin_family = AF_INET;
-  address.sin_port = (port);
+  address.sin_port = htons(port);
   address.sin_addr.s_addr = addr.s_addr;
 
   connected_socket = socket(AF_INET, SOCK_STREAM, 0);
@@ -260,7 +328,8 @@ int get_connection(freenet_connection *connection, u_short port,
   starttime = time(NULL);
   while(connected_socket < 0) {
     b = sizeof(incoming);
-    connected_socket = accept(listening_socket, &incoming, &b);
+    connected_socket = accept(listening_socket,
+          (struct sockaddr *)&incoming, &b);
     if (connected_socket < 0) {
       /* Either a real error occured, or blocking was interrupted for
          some reason.  Only abort execution if a real error occured. */
@@ -280,7 +349,10 @@ int get_connection(freenet_connection *connection, u_short port,
       }
     }
 
-    close(listening_socket); /* Close this socket */
+    status = close(listening_socket); /* Close this socket */
+    if (status != 0) {
+      return FNS_CLOSE_FAILED;
+    }
 
   }
 
@@ -567,68 +639,6 @@ int reply_handshake (freenet_connection *connection, freenet_message *request)
 }
 
 
-int string_to_msgtype (const char *typestr)
-{
-  if (strcmp(typestr, "StoreData") == 0) {
-    return FN_STOREDATA_MSG;
-  } else if (strcmp(typestr, "HandshakeRequest") == 0) {
-    return FN_HANDSHAKEREQUEST_MSG;
-  } else if (strcmp(typestr, "HandshakeReply") == 0) {
-    return FN_HANDSHAKEREPLY_MSG;
-  } else if (strcmp(typestr, "QueryRestarted") == 0) {
-    return FN_QUERYRESTARTED_MSG;
-  } else if (strcmp(typestr, "DataRequest") == 0) {
-    return FN_DATAREQUEST_MSG;
-  } else if (strcmp(typestr, "DataReply") == 0) {
-    return FN_DATAREPLY_MSG;
-  } else if (strcmp(typestr, "TimedOut") == 0) {
-    return FN_TIMEDOUT_MSG;
-  } else if (strcmp(typestr, "RequestFailed") == 0) {
-    return FN_REQUESTFAILED_MSG;
-  } else if (strcmp(typestr, "InsertRequest") == 0) {
-    return FN_INSERTREQUEST_MSG;
-  } else if (strcmp(typestr, "InsertReply") == 0) {
-    return FN_INSERTREPLY_MSG;
-  } else if (strcmp(typestr, "DataInsert") == 0) {
-    return FN_DATAINSERT_MSG;
-  } else {
-    return FN_UNKNOWN_MSG;
-  }
-}
-
-
-int msgtype_to_string (int msgtype, char *typestr)
-{
-  if (msgtype == FN_STOREDATA_MSG) {
-    strcpy(typestr, "StoreData");
-  } else if (msgtype == FN_HANDSHAKEREQUEST_MSG) {
-    strcpy(typestr, "HandshakeRequest");
-  } else if (msgtype == FN_HANDSHAKEREPLY_MSG) {
-    strcpy(typestr, "HandshakeReply");
-  } else if (msgtype == FN_QUERYRESTARTED_MSG) {
-    strcpy(typestr, "QueryRestarted");
-  } else if (msgtype == FN_DATAREQUEST_MSG) {
-    strcpy(typestr, "DataRequest");
-  } else if (msgtype == FN_DATAREPLY_MSG) {
-    strcpy(typestr, "DataReply");
-  } else if (msgtype == FN_TIMEDOUT_MSG) {
-    strcpy(typestr, "TimedOut");
-  } else if (msgtype == FN_REQUESTFAILED_MSG) {
-    strcpy(typestr, "RequestFailed");
-  } else if (msgtype == FN_INSERTREQUEST_MSG) {
-    strcpy(typestr, "InsertRequest");
-  } else if (msgtype == FN_INSERTREPLY_MSG) {
-    strcpy(typestr, "InsertReply");
-  } else if (msgtype == FN_DATAINSERT_MSG) {
-    strcpy(typestr, "DataInsert");
-  } else {
-    return FNS_UNKNOWN_MSG_TYPE;
-  }
-
-  return FNS_SUCCESS;
-}
-
-
 int freenet_senddata(freenet_connection *connection, const char *buffer,
                      int len)
 {
@@ -917,7 +927,10 @@ int freenet_recvmsg (freenet_connection *connection, freenet_message *message)
 
   status = internal_recvmsg(connection, message);
   if ((status == FNS_CONNECTION_GONE) && (connection->expect_callback)) {
-    close(connection->socket);
+    status = close(connection->socket);
+    if (status != 0) {
+      return FNS_CLOSE_FAILED;
+    }
     status = freenet_get_connection(connection, 6666);
     if (status != FNS_SUCCESS) {
       return status;
@@ -947,14 +960,14 @@ int freenet_recvmsg (freenet_connection *connection, freenet_message *message)
 
 
 int freenet_connect (freenet_connection *connection, char *hostaddress,
-                     char *service)
+                     int port)
 {
   int status;
 
   connection->expect_callback = FN_TRUE;
   connection->timeout = 30;
 
-  status = open_connection(connection, hostaddress, service);
+  status = open_connection(connection, hostaddress, port);
   if (status != FNS_SUCCESS) {
     return status;
   }
@@ -1022,3 +1035,30 @@ int freenet_auth_connection (freenet_connection *connection)
 
   return FNS_SUCCESS;
 }
+
+
+int freenet_close_connection (freenet_connection *connection)
+{
+  int status;
+
+  status = close(connection->socket);
+  if (status != 0) {
+    return FNS_CLOSE_FAILED;
+  }
+
+  return FNS_SUCCESS;
+}
+
+
+const char *freenet_strerror(int status)
+{
+  int i;
+
+  for(i = 0; errstrs[i].str != NULL; i++) {
+    if(errstrs[i].status == status) {
+      return errstrs[i].str;
+    }
+  }
+
+  return "Unknown status code";
+}
