@@ -24,7 +24,7 @@ int rijndaelKeySched(word8 k[MAXKC][4], word8 rk[MAXROUNDS+1][4][4], int ROUNDS)
 
 int rijndaelKeyEncToDec(word8 W[MAXROUNDS+1][4][4], int ROUNDS);
 
-int rijndaelEncrypt(word8 a[16], word8 b[16], word8 rk[MAXROUNDS+1][4][4], int ROUNDS);
+int rijndaelEncrypt(const word8 a[16], word8 b[16], word8 rk[MAXROUNDS+1][4][4], int ROUNDS);
 
 #ifdef INTERMEDIATE_VALUE_KAT
 int rijndaelEncryptRound(word8 a[4][4], word8 rk[MAXROUNDS+1][4][4], int ROUNDS, int rounds);
