@@ -20,7 +20,7 @@
 #include "rijndael-alg-fst.h"
 #include "rijndael-api-fst.h"
 
-int rijndael_makeKey(rijndael_keyInstance *key, BYTE direction, int keyLen, char *keyMaterial) {
+int rijndael_makeKey(rijndael_keyInstance *key, BYTE direction, int keyLen, const char *keyMaterial) {
         word8 k[MAXKC][4];
         int i;
         char *keyMat;
@@ -42,7 +42,11 @@ int rijndael_makeKey(rijndael_keyInstance *key, BYTE direction, int keyLen, char
         }
 
         if (keyMaterial != NULL) {
+#ifdef BINARY_KEY_MATERIAL
+				memcpy(key->keyMaterial, keyMaterial, keyLen/8);
+#else
                 strncpy(key->keyMaterial, keyMaterial, keyLen/4);
+#endif
         }
 
         key->ROUNDS = keyLen/32 + 6;
@@ -116,7 +120,7 @@ int rijndael_cipherInit(rijndael_cipherInstance *cipher, BYTE mode, char *IV) {
 }
 
 int rijndael_blockEncrypt(rijndael_cipherInstance *cipher, rijndael_keyInstance *key,
-                BYTE *input, int inputLen, BYTE *outBuffer) {
+                const BYTE *input, int inputLen, BYTE *outBuffer) {
         int i, k, numBlocks;
         word8 block[16], iv[4][4];
 
