@@ -27,7 +27,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h> /* for memcmp() */
-#include <stdint.h>
+#include <sys/types.h>
 
 #include <twofish.h>
 
@@ -38,7 +38,7 @@ static const char *selftest(void);
 /* These two tables are the q0 and q1 permutations, exactly as described in
  * the Twofish paper. */
 
-static const uint8_t q0[256] = {
+static const u_int8_t q0[256] = {
    0xA9, 0x67, 0xB3, 0xE8, 0x04, 0xFD, 0xA3, 0x76, 0x9A, 0x92, 0x80, 0x78,
    0xE4, 0xDD, 0xD1, 0x38, 0x0D, 0xC6, 0x35, 0x98, 0x18, 0xF7, 0xEC, 0x6C,
    0x43, 0x75, 0x37, 0x26, 0xFA, 0x13, 0x94, 0x48, 0xF2, 0xD0, 0x8B, 0x30,
@@ -63,7 +63,7 @@ static const uint8_t q0[256] = {
    0x4A, 0x5E, 0xC1, 0xE0
 };
 
-static const uint8_t q1[256] = {
+static const u_int8_t q1[256] = {
    0x75, 0xF3, 0xC6, 0xF4, 0xDB, 0x7B, 0xFB, 0xC8, 0x4A, 0xD3, 0xE6, 0x6B,
    0x45, 0x7D, 0xE8, 0x4B, 0xD6, 0x32, 0xD8, 0xFD, 0x37, 0x71, 0xF1, 0xE1,
    0x30, 0x0F, 0xF8, 0x1B, 0x87, 0xFA, 0x06, 0x3F, 0x5E, 0xBA, 0xAE, 0x5B,
@@ -101,7 +101,7 @@ static const uint8_t q1[256] = {
  * by Schneier et al, and I'm casually glossing over the byte/word
  * conversion issues. */
 
-static const uint32_t mds[4][256] = {
+static const u_int32_t mds[4][256] = {
    {0xBCBC3275, 0xECEC21F3, 0x202043C6, 0xB3B3C9F4, 0xDADA03DB, 0x02028B7B,
     0xE2E22BFB, 0x9E9EFAC8, 0xC9C9EC4A, 0xD4D409D3, 0x18186BE6, 0x1E1E9F6B,
     0x98980E45, 0xB2B2387D, 0xA6A6D2E8, 0x2626B74B, 0x3C3C57D6, 0x93938A32,
@@ -312,7 +312,7 @@ static const uint32_t mds[4][256] = {
  * see a non-horrible way of avoiding them, and I did manage to group the
  * statements so that each if covers four group multiplications. */
 
-static const uint8_t poly_to_exp[255] = {
+static const u_int8_t poly_to_exp[255] = {
    0x00, 0x01, 0x17, 0x02, 0x2E, 0x18, 0x53, 0x03, 0x6A, 0x2F, 0x93, 0x19,
    0x34, 0x54, 0x45, 0x04, 0x5C, 0x6B, 0xB6, 0x30, 0xA6, 0x94, 0x4B, 0x1A,
    0x8C, 0x35, 0x81, 0x55, 0xAA, 0x46, 0x0D, 0x05, 0x24, 0x5D, 0x87, 0x6C,
@@ -337,7 +337,7 @@ static const uint8_t poly_to_exp[255] = {
    0x85, 0xC8, 0xA1
 };
 
-static const uint8_t exp_to_poly[492] = {
+static const u_int8_t exp_to_poly[492] = {
    0x01, 0x02, 0x04, 0x08, 0x10, 0x20, 0x40, 0x80, 0x4D, 0x9A, 0x79, 0xF2,
    0xA9, 0x1F, 0x3E, 0x7C, 0xF8, 0xBD, 0x37, 0x6E, 0xDC, 0xF5, 0xA7, 0x03,
    0x06, 0x0C, 0x18, 0x30, 0x60, 0xC0, 0xCD, 0xD7, 0xE3, 0x8B, 0x5B, 0xB6,
@@ -384,7 +384,7 @@ static const uint8_t exp_to_poly[492] = {
 
 /* The table constants are indices of
  * S-box entries, preprocessed through q0 and q1. */
-static uint8_t calc_sb_tbl[512] = {
+static u_int8_t calc_sb_tbl[512] = {
     0xA9, 0x75, 0x67, 0xF3, 0xB3, 0xC6, 0xE8, 0xF4,
     0x04, 0xDB, 0xFD, 0x7B, 0xA3, 0xFB, 0x76, 0xC8,
     0x9A, 0x4A, 0x92, 0xD3, 0x80, 0xE6, 0x78, 0x6B,
@@ -541,20 +541,20 @@ static uint8_t calc_sb_tbl[512] = {
  * keys, despite the API that looks like it might support other sizes. */
 
 int
-twofish_setkey (TWOFISH_context *ctx, const uint8_t *key, const unsigned keylen)
+twofish_setkey (TWOFISH_context *ctx, const u_int8_t *key, const unsigned keylen)
 {
     int i, j, k;
 
     /* Temporaries for CALC_K. */
-    uint32_t x, y;
+    u_int32_t x, y;
 
     /* The S vector used to key the S-boxes, split up into individual bytes.
      * 128-bit keys use only sa through sh; 256-bit use all of them. */
-    uint8_t sa = 0, sb = 0, sc = 0, sd = 0, se = 0, sf = 0, sg = 0, sh = 0;
-    uint8_t si = 0, sj = 0, sk = 0, sl = 0, sm = 0, sn = 0, so = 0, sp = 0;
+    u_int8_t sa = 0, sb = 0, sc = 0, sd = 0, se = 0, sf = 0, sg = 0, sh = 0;
+    u_int8_t si = 0, sj = 0, sk = 0, sl = 0, sm = 0, sn = 0, so = 0, sp = 0;
 
     /* Temporary for CALC_S. */
-    uint8_t tmp;
+    u_int8_t tmp;
 
     /* Flags for self-test. */
     static int initialized = 0;
@@ -735,14 +735,14 @@ twofish_setkey (TWOFISH_context *ctx, const uint8_t *key, const unsigned keylen)
 
 /* Encrypt one block.  in and out may be the same. */
 
-void twofish_encrypt (const TWOFISH_context *ctx, uint8_t *out,
-                      const uint8_t *in)
+void twofish_encrypt (const TWOFISH_context *ctx, u_int8_t *out,
+                      const u_int8_t *in)
 {
    /* The four 32-bit chunks of the text. */
-   uint32_t a, b, c, d;
+   u_int32_t a, b, c, d;
 
    /* Temporaries used by the round function. */
-   uint32_t x, y;
+   u_int32_t x, y;
 
    /* Input whitening and packing. */
    INPACK (0, a, 0);
@@ -769,14 +769,14 @@ void twofish_encrypt (const TWOFISH_context *ctx, uint8_t *out,
 
 /* Decrypt one block.  in and out may be the same. */
 
-void twofish_decrypt (const TWOFISH_context *ctx, uint8_t *out,
-                      const uint8_t *in)
+void twofish_decrypt (const TWOFISH_context *ctx, u_int8_t *out,
+                      const u_int8_t *in)
 {
    /* The four 32-bit chunks of the text. */
-   uint32_t a, b, c, d;
+   u_int32_t a, b, c, d;
 
    /* Temporaries used by the round function. */
-   uint32_t x, y;
+   u_int32_t x, y;
 
    /* Input whitening and packing. */
    INPACK (0, c, 4);
@@ -807,36 +807,36 @@ static const char*
 selftest (void)
 {
    TWOFISH_context ctx; /* Expanded key. */
-   uint8_t scratch[16];    /* Encryption/decryption result buffer. */
+   u_int8_t scratch[16];    /* Encryption/decryption result buffer. */
 
    /* Test vectors for single encryption/decryption.  Note that I am using
     * the vectors from the Twofish paper's "known answer test", I=3 for
     * 128-bit and I=4 for 256-bit, instead of the all-0 vectors from the
     * "intermediate value test", because an all-0 key would trigger all the
     * special cases in the RS matrix multiply, leaving the math untested. */
-   static const uint8_t plaintext[16] = {
+   static const u_int8_t plaintext[16] = {
       0xD4, 0x91, 0xDB, 0x16, 0xE7, 0xB1, 0xC3, 0x9E,
       0x86, 0xCB, 0x08, 0x6B, 0x78, 0x9F, 0x54, 0x19
    };
-   static const uint8_t key[16] = {
+   static const u_int8_t key[16] = {
       0x9F, 0x58, 0x9F, 0x5C, 0xF6, 0x12, 0x2C, 0x32,
       0xB6, 0xBF, 0xEC, 0x2F, 0x2A, 0xE8, 0xC3, 0x5A
    };
-   static const uint8_t ciphertext[16] = {
+   static const u_int8_t ciphertext[16] = {
       0x01, 0x9F, 0x98, 0x09, 0xDE, 0x17, 0x11, 0x85,
       0x8F, 0xAA, 0xC3, 0xA3, 0xBA, 0x20, 0xFB, 0xC3
    };
-   static const uint8_t plaintext_256[16] = {
+   static const u_int8_t plaintext_256[16] = {
       0x90, 0xAF, 0xE9, 0x1B, 0xB2, 0x88, 0x54, 0x4F,
       0x2C, 0x32, 0xDC, 0x23, 0x9B, 0x26, 0x35, 0xE6
    };
-   static const uint8_t key_256[32] = {
+   static const u_int8_t key_256[32] = {
       0xD4, 0x3B, 0xB7, 0x55, 0x6E, 0xA3, 0x2E, 0x46,
       0xF2, 0xA2, 0x82, 0xB7, 0xD4, 0x5B, 0x4E, 0x0D,
       0x57, 0xFF, 0x73, 0x9D, 0x4D, 0xC9, 0x2C, 0x1B,
       0xD7, 0xFC, 0x01, 0x70, 0x0C, 0xC8, 0x21, 0x6F
    };
-   static const uint8_t ciphertext_256[16] = {
+   static const u_int8_t ciphertext_256[16] = {
       0x6C, 0xB4, 0x56, 0x1C, 0x40, 0xBF, 0x0A, 0x97,
       0x05, 0x93, 0x1C, 0xB6, 0xD4, 0x08, 0xE7, 0xFA
    };
@@ -885,7 +885,7 @@ main()
    clock_t timer; /* For computing elapsed time. */
 
    /* Test buffer. */
-   uint8_t buffer[4][16] = {
+   u_int8_t buffer[4][16] = {
       {0x00, 0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77,
        0x88, 0x99, 0xAA, 0xBB, 0xCC, 0xDD, 0xEE, 0xFF},
       {0x0F, 0x1E, 0x2D, 0x3C, 0x4B, 0x5A, 0x69, 0x78,
@@ -897,7 +897,7 @@ main()
    };
 
    /* Expected outputs for the million-operation test */
-   static const uint8_t test_encrypt[4][16] = {
+   static const u_int8_t test_encrypt[4][16] = {
       {0xC8, 0x23, 0xB8, 0xB7, 0x6B, 0xFE, 0x91, 0x13,
        0x2F, 0xA7, 0x5E, 0xE6, 0x94, 0x77, 0x6F, 0x6B},
       {0x90, 0x36, 0xD8, 0x29, 0xD5, 0x96, 0xC2, 0x8E,
@@ -907,7 +907,7 @@ main()
       {0x7A, 0x88, 0xFB, 0xEB, 0x90, 0xA4, 0xB4, 0xA8,
        0x43, 0xA3, 0x1D, 0xF1, 0x26, 0xC4, 0x53, 0x57}
    };
-   static const uint8_t test_decrypt[4][16] = {
+   static const u_int8_t test_decrypt[4][16] = {
       {0x00, 0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77,
        0x88, 0x99, 0xAA, 0xBB, 0xCC, 0xDD, 0xEE, 0xFF},
       {0x0F, 0x1E, 0x2D, 0x3C, 0x4B, 0x5A, 0x69, 0x78,
